@@ -2221,6 +2221,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
       (void) WriteBlobString(image,buffer);
     }
   (void) WriteBlobString(image,"%%EOF\n");
-  (void) CloseBlob(image);
-  return(MagickTrue);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  return(status);
 }
