@@ -1133,7 +1133,10 @@ static Image *ReadSIXELImage(const ImageInfo *image_info,ExceptionInfo *exceptio
   */
   sixel_pixels=(unsigned char *) RelinquishMagickMemory(sixel_pixels);
   sixel_palette=(unsigned char *) RelinquishMagickMemory(sixel_palette);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
+  if (status == MagickFalse)
+    return(DestroyImageList(image));
   return(GetFirstImageInList(image));
 }
 
@@ -1372,6 +1375,7 @@ static MagickBooleanType WriteSIXELImage(const ImageInfo *image_info,
     sixel_palette, image->colors, -1, output);
   sixel_pixels =(unsigned char *) RelinquishMagickMemory(sixel_pixels);
   output = (sixel_output_t *) RelinquishMagickMemory(output);
-  (void) CloseBlob(image);
+  if (CloseBlob(image) == MagickFalse)
+    status=MagickFalse;
   return(status);
 }
