@@ -148,9 +148,6 @@ struct _FxInfo
   RandomInfo
     *random_info;
 
-  MagickSizeType
-    cycles;
-
   ExceptionInfo
     *exception;
 };
@@ -427,7 +424,7 @@ static double FxChannelStatistics(FxInfo *fx_info,const Image *image,
 
       (void) GetImageChannelKurtosis(image,channel,&kurtosis,&skewness,
         exception);
-      statistic=kurtosis;
+      statistic=QuantumRange*kurtosis;
     }
   if (LocaleNCompare(symbol,"maxima",6) == 0)
     {
@@ -465,7 +462,7 @@ static double FxChannelStatistics(FxInfo *fx_info,const Image *image,
 
       (void) GetImageChannelKurtosis(image,channel,&kurtosis,&skewness,
         exception);
-      statistic=skewness;
+      statistic=QuantumRange*skewness;
     }
   if (LocaleNCompare(symbol,"standard_deviation",18) == 0)
     {
@@ -2166,7 +2163,7 @@ static double FxEvaluateSubexpression(FxInfo *fx_info,const ChannelType channel,
           FxParseConditional(subexpression,',',p,q);
           for (alpha=0.0; ; )
           {
-            if (((fx_info->cycles++ % 8192) == 0) && (GetMagickTTL() <= 0))
+            if (IsImageTTLExpired(fx_info->images) != MagickFalse)
               (void) ThrowMagickException(exception,GetMagickModule(),
                 ResourceLimitFatalError,"TimeLimitExceeded","`%s'",
                 fx_info->images->filename);
@@ -2241,7 +2238,7 @@ static double FxEvaluateSubexpression(FxInfo *fx_info,const ChannelType channel,
           FxParseConditional(subexpression,',',p,q);
           for (alpha=0.0; ; )
           {
-            if (((fx_info->cycles++ % 8192) == 0) && (GetMagickTTL() <= 0))
+            if (IsImageTTLExpired(fx_info->images) != MagickFalse)
               (void) ThrowMagickException(exception,GetMagickModule(),
                 ResourceLimitFatalError,"TimeLimitExceeded","`%s'",
                 fx_info->images->filename);
@@ -2623,7 +2620,7 @@ static double FxEvaluateSubexpression(FxInfo *fx_info,const ChannelType channel,
           FxParseConditional(subexpression,',',p,q);
           for (alpha=0.0; ; )
           {
-            if (((fx_info->cycles++ % 8192) == 0) && (GetMagickTTL() <= 0))
+            if (IsImageTTLExpired(fx_info->images) != MagickFalse)
               (void) ThrowMagickException(exception,GetMagickModule(),
                 ResourceLimitFatalError,"TimeLimitExceeded","`%s'",
                 fx_info->images->filename);
