@@ -87,7 +87,7 @@ static inline void *NTAcquireQuantumMemory(const size_t count,
 }
 
 extern MagickPrivate char
-  *NTGetLastError(void);
+  *NTGetEnvironmentValue(const char *);
 
 #if !defined(MAGICKCORE_LTDL_DELEGATE)
 extern MagickPrivate const char
