@@ -147,22 +147,17 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
     *floodplane_image;
 
   MagickBooleanType
-    skip;
+    skip,
+    status;
 
   MagickPixelPacket
-    fill,
     pixel;
 
   MemoryInfo
     *segment_info;
 
-  PixelPacket
-    fill_color;
-
-  SegmentInfo
-    *s;
-
   SegmentInfo
+    *s,
     *segment_stack;
 
   ssize_t
@@ -200,7 +195,11 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
   floodplane_image=CloneImage(image,0,0,MagickTrue,&image->exception);
   if (floodplane_image == (Image *) NULL)
     return(MagickFalse);
-  (void) SetImageAlphaChannel(floodplane_image,OpaqueAlphaChannel);
+  floodplane_image->matte=MagickFalse;
+  floodplane_image->colorspace=GRAYColorspace;
+  (void) QueryColorCompliance("#000",AllCompliance,
+    &floodplane_image->background_color,exception);
+  (void) SetImageBackgroundColor(floodplane_image);
   segment_info=AcquireVirtualMemory(MaxStacksize,sizeof(*segment_stack));
   if (segment_info == (MemoryInfo *) NULL)
     {
@@ -216,7 +215,6 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
   y=y_offset;
   start=0;
   s=segment_stack;
-  GetMagickPixelPacket(image,&fill);
   GetMagickPixelPacket(image,&pixel);
   image_view=AcquireVirtualCacheView(image,exception);
   floodplane_view=AcquireAuthenticCacheView(floodplane_image,exception);
@@ -230,12 +228,12 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
     const PixelPacket
       *magick_restrict p;
 
-    ssize_t
-      x;
-
     PixelPacket
       *magick_restrict q;
 
+    ssize_t
+      x;
+
     /*
       Pop segment off stack.
     */
@@ -257,12 +255,12 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
     q+=x1;
     for (x=x1; x >= 0; x--)
     {
-      if (q->opacity == (Quantum) TransparentOpacity)
+      if (GetPixelGray(q) != 0)
         break;
       SetMagickPixelPacket(image,p,indexes+x,&pixel);
       if (IsMagickColorSimilar(&pixel,target) == invert)
         break;
-      q->opacity=(Quantum) TransparentOpacity;
+      SetPixelGray(q,QuantumRange);
       p--;
       q--;
     }
@@ -292,12 +290,12 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
               indexes=GetCacheViewVirtualIndexQueue(image_view);
               for ( ; x < (ssize_t) image->columns; x++)
               {
-                if (q->opacity == (Quantum) TransparentOpacity)
+                if (GetPixelGray(q) != 0)
                   break;
                 SetMagickPixelPacket(image,p,indexes+x,&pixel);
                 if (IsMagickColorSimilar(&pixel,target) == invert)
                   break;
-                q->opacity=(Quantum) TransparentOpacity;
+                SetPixelGray(q,QuantumRange);
                 p++;
                 q++;
               }
@@ -321,7 +319,7 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
           indexes=GetCacheViewVirtualIndexQueue(image_view);
           for ( ; x <= x2; x++)
           {
-            if (q->opacity == (Quantum) TransparentOpacity)
+            if (GetPixelGray(q) != 0)
               break;
             SetMagickPixelPacket(image,p,indexes+x,&pixel);
             if (IsMagickColorSimilar(&pixel,target) != invert)
@@ -333,6 +331,11 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
       start=x;
     } while (x <= x2);
   }
+  status=MagickTrue;
+#if defined(MMAGICKCORE_OPENMP_SUPPORT)
+  #pragma omp parallel for schedule(static) shared(status) \
+    magick_number_threads(floodplane_image,image,image->rows,2)
+#endif
   for (y=0; y < (ssize_t) image->rows; y++)
   {
     const PixelPacket
@@ -341,26 +344,37 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
     IndexPacket
       *magick_restrict indexes;
 
-    ssize_t
-      x;
-
     PixelPacket
       *magick_restrict q;
 
+    ssize_t
+      x;
+
     /*
       Tile fill color onto floodplane.
     */
-    p=GetCacheViewVirtualPixels(floodplane_view,0,y,image->columns,1,
-      exception);
+    if (status == MagickFalse)
+      continue;
+    p=GetCacheViewVirtualPixels(floodplane_view,0,y,image->columns,1,exception);
     q=GetCacheViewAuthenticPixels(image_view,0,y,image->columns,1,exception);
     if ((p == (const PixelPacket *) NULL) || (q == (PixelPacket *) NULL))
-      break;
+      {
+        status=MagickFalse;
+        continue;
+      }
     indexes=GetCacheViewAuthenticIndexQueue(image_view);
     for (x=0; x < (ssize_t) image->columns; x++)
     {
-      if (GetPixelOpacity(p) != OpaqueOpacity)
+      if (GetPixelGray(p) != 0)
         {
+          MagickPixelPacket
+            fill;
+
+          PixelPacket
+            fill_color;
+
           (void) GetFillColor(draw_info,x,y,&fill_color);
+          GetMagickPixelPacket(image,&fill);
           SetMagickPixelPacket(image,&fill_color,(IndexPacket *) NULL,&fill);
           if (image->colorspace == CMYKColorspace)
             ConvertRGBToCMYK(&fill);
@@ -381,7 +395,7 @@ MagickExport MagickBooleanType FloodfillPaintImage(Image *image,
       q++;
     }
     if (SyncCacheViewAuthenticPixels(image_view,exception) == MagickFalse)
-      break;
+      status=MagickFalse;
   }
   floodplane_view=DestroyCacheView(floodplane_view);
   image_view=DestroyCacheView(image_view);
