@@ -60,6 +60,7 @@
 #include "magick/string_.h"
 #include "magick/thread_.h"
 #include "magick/thread-private.h"
+#include "magick/timer-private.h"
 #include "magick/utility-private.h"
 #if defined(MAGICKCORE_HAVE_GETENTROPY)
 #include <sys/random.h>
@@ -105,7 +106,7 @@ struct _RandomInfo
   SemaphoreInfo
     *semaphore;
 
-  ssize_t
+  time_t
     timestamp;
 
   size_t
@@ -192,7 +193,7 @@ MagickExport RandomInfo *AcquireRandomInfo(void)
   random_info->protocol_major=RandomProtocolMajorVersion;
   random_info->protocol_minor=RandomProtocolMinorVersion;
   random_info->semaphore=AllocateSemaphoreInfo();
-  random_info->timestamp=(ssize_t) time(0);
+  random_info->timestamp=GetMagickTime();
   random_info->signature=MagickCoreSignature;
   /*
     Seed random nonce.
