@@ -18,7 +18,7 @@
 %                               March 2001                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2021 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999 ImageMagick Studio LLC, a non-profit organization           %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -51,12 +51,20 @@
 /*
   Define declarations.
 */
+#if defined(__APPLE__)
+  #include "TargetConditionals.h"
+  #if TARGET_OS_IOS || TARGET_OS_WATCH || TARGET_OS_TV
+    #define system(s) ((s)==NULL ? 0 : -1)
+  #endif // end iOS
+#elif defined(__ANDROID__)
+  #define system(s) ((s)==NULL ? 0 : -1)
+#endif
 #define CIEEpsilon  (216.0/24389.0)
 #define CIEK  (24389.0/27.0)
-#define D65X  0.950456
+#define D65X  0.95047
 #define D65Y  1.0
-#define D65Z  1.088754
-#define ReferenceEpsilon  (QuantumRange*1.0e-2)
+#define D65Z  1.08883
+#define ReferenceEpsilon  ((double) QuantumRange*1.0e-2)
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -74,18 +82,11 @@
 %
 %  The format of the ValidateColorspaces method is:
 %
-%      size_t ValidateColorspaces(ImageInfo *image_info,size_t *fails,
-%        ExceptionInfo *exception)
+%      size_t ValidateColorspaces(size_t *fails,ExceptionInfo *exception)
 %
 %  A description of each parameter follows:
 %
-%    o image_info: the image info.
-%
-%    o reference_filename: the reference image filename.
-%
-%    o output_filename: the output image filename.
-%
-%    o fail: return the number of validation tests that pass.
+%    o fails: return the number of validation tests that pass.
 %
 %    o exception: return any errors or warnings in this structure.
 %
@@ -183,9 +184,9 @@ static inline void ConvertXYZToRGB(const double x,const double y,const double z,
   r=3.2406*x-1.5372*y-0.4986*z;
   g=(-0.9689*x+1.8758*y+0.0415*z);
   b=0.0557*x-0.2040*y+1.0570*z;
-  *red=ClampToQuantum(EncodePixelGamma(QuantumRange*r));
-  *green=ClampToQuantum(EncodePixelGamma(QuantumRange*g));
-  *blue=ClampToQuantum(EncodePixelGamma(QuantumRange*b));
+  *red=ClampToQuantum(EncodePixelGamma((double) QuantumRange*r));
+  *green=ClampToQuantum(EncodePixelGamma((double) QuantumRange*g));
+  *blue=ClampToQuantum(EncodePixelGamma((double) QuantumRange*b));
 }
 
 static inline void ConvertLabToRGB(const double L,const double a,
@@ -217,11 +218,11 @@ static void ConvertRGBToYCbCr(const double red,const double green,
 static void ConvertYPbPrToRGB(const double Y,const double Pb,const double Pr,
   Quantum *red,Quantum *green,Quantum *blue)
 {
-  *red=ClampToQuantum(QuantumRange*(0.99999999999914679361*Y-
+  *red=ClampToQuantum((double) QuantumRange*(0.99999999999914679361*Y-
     1.2188941887145875e-06*(Pb-0.5)+1.4019995886561440468*(Pr-0.5)));
-  *green=ClampToQuantum(QuantumRange*(0.99999975910502514331*Y-
+  *green=ClampToQuantum((double) QuantumRange*(0.99999975910502514331*Y-
     0.34413567816504303521*(Pb-0.5)-0.71413649331646789076*(Pr-0.5)));
-  *blue=ClampToQuantum(QuantumRange*(1.00000124040004623180*Y+
+  *blue=ClampToQuantum((double) QuantumRange*(1.00000124040004623180*Y+
     1.77200006607230409200*(Pb-0.5)+2.1453384174593273e-06*(Pr-0.5)));
 }
 
@@ -309,9 +310,9 @@ static inline void ConvertLuvToXYZ(const double L,const double u,const double v,
   else
     *Y=L/CIEK;
   *X=((*Y*((39.0*L/(v+13.0*L*(9.0*D65Y/(D65X+15.0*D65Y+3.0*D65Z))))-5.0))+
-    5.0*(*Y))/((((52.0f*L/(u+13.0*L*(4.0*D65X/(D65X+15.0*D65Y+3.0*D65Z))))-1.0)/
+    5.0*(*Y))/((((52.0*L/(u+13.0*L*(4.0*D65X/(D65X+15.0*D65Y+3.0*D65Z))))-1.0)/
     3.0)-(-1.0/3.0));
-  *Z=(*X*(((52.0f*L/(u+13.0*L*(4.0*D65X/(D65X+15.0*D65Y+3.0*D65Z))))-1.0)/3.0))-
+  *Z=(*X*(((52.0*L/(u+13.0*L*(4.0*D65X/(D65X+15.0*D65Y+3.0*D65Z))))-1.0)/3.0))-
     5.0*(*Y);
 }
 
@@ -338,12 +339,12 @@ static void ConvertRGBToYDbDr(const double red,const double green,
 static void ConvertYDbDrToRGB(const double Y,const double Db,const double Dr,
   Quantum *red,Quantum *green,Quantum *blue)
 {
-  *red=ClampToQuantum(QuantumRange*(Y+9.2303716147657e-05*(Db-0.5)-
-    0.52591263066186533*(Dr-0.5)));
-  *green=ClampToQuantum(QuantumRange*(Y-0.12913289889050927*(Db-0.5)+
-    0.26789932820759876*(Dr-0.5)));
-  *blue=ClampToQuantum(QuantumRange*(Y+0.66467905997895482*(Db-0.5)-
-    7.9202543533108e-05*(Dr-0.5)));
+  *red=ClampToQuantum((double) QuantumRange*(Y+9.2303716147657e-05*
+    (Db-0.5)-0.52591263066186533*(Dr-0.5)));
+  *green=ClampToQuantum((double) QuantumRange*(Y-0.12913289889050927*
+    (Db-0.5)+0.26789932820759876*(Dr-0.5)));
+  *blue=ClampToQuantum((double) QuantumRange*(Y+0.66467905997895482*
+    (Db-0.5)-7.9202543533108e-05*(Dr-0.5)));
 }
 
 static void ConvertRGBToYIQ(const double red,const double green,
@@ -357,12 +358,12 @@ static void ConvertRGBToYIQ(const double red,const double green,
 static void ConvertYIQToRGB(const double Y,const double I,const double Q,
   Quantum *red,Quantum *green,Quantum *blue)
 {
-  *red=ClampToQuantum(QuantumRange*(Y+0.9562957197589482261*(I-0.5)+
-    0.6210244164652610754*(Q-0.5)));
-  *green=ClampToQuantum(QuantumRange*(Y-0.2721220993185104464*(I-0.5)-
-    0.6473805968256950427*(Q-0.5)));
-  *blue=ClampToQuantum(QuantumRange*(Y-1.1069890167364901945*(I-0.5)+
-    1.7046149983646481374*(Q-0.5)));
+  *red=ClampToQuantum((double) QuantumRange*(Y+0.9562957197589482261*
+    (I-0.5)+0.6210244164652610754*(Q-0.5)));
+  *green=ClampToQuantum((double) QuantumRange*(Y-0.2721220993185104464*
+    (I-0.5)-0.6473805968256950427*(Q-0.5)));
+  *blue=ClampToQuantum((double) QuantumRange*(Y-1.1069890167364901945*
+    (I-0.5)+1.7046149983646481374*(Q-0.5)));
 }
 
 static void ConvertRGBToYUV(const double red,const double green,
@@ -376,12 +377,12 @@ static void ConvertRGBToYUV(const double red,const double green,
 static void ConvertYUVToRGB(const double Y,const double U,const double V,
   Quantum *red,Quantum *green,Quantum *blue)
 {
-  *red=ClampToQuantum(QuantumRange*(Y-3.945707070708279e-05*(U-0.5)+
-    1.1398279671717170825*(V-0.5)));
-  *green=ClampToQuantum(QuantumRange*(Y-0.3946101641414141437*(U-0.5)-
-    0.5805003156565656797*(V-0.5)));
-  *blue=ClampToQuantum(QuantumRange*(Y+2.0319996843434342537*(U-0.5)-
-    4.813762626262513e-04*(V-0.5)));
+  *red=ClampToQuantum((double) QuantumRange*(Y-3.945707070708279e-05*
+    (U-0.5)+1.1398279671717170825*(V-0.5)));
+  *green=ClampToQuantum((double) QuantumRange*(Y-0.3946101641414141437*
+    (U-0.5)-0.5805003156565656797*(V-0.5)));
+  *blue=ClampToQuantum((double) QuantumRange*(Y+2.0319996843434342537*
+    (U-0.5)-4.813762626262513e-04*(V-0.5)));
 }
 
 static MagickBooleanType ValidateHSIToRGB()
@@ -393,9 +394,9 @@ static MagickBooleanType ValidateHSIToRGB()
 
   (void) FormatLocaleFile(stdout,"  HSIToRGB");
   ConvertHSIToRGB(111.244375/360.0,0.295985,0.658734,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -408,11 +409,12 @@ static MagickBooleanType ValidateRGBToHSI()
     s;
 
   (void) FormatLocaleFile(stdout,"  RGBToHSI");
-  ConvertRGBToHSI(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&h,&s,&i);
-  if ((fabs(h-111.244374/360.0) >= ReferenceEpsilon) ||
-      (fabs(s-0.295985) >= ReferenceEpsilon) ||
-      (fabs(i-0.658734) >= ReferenceEpsilon))
+  ConvertRGBToHSI(0.545877*(double) QuantumRange,0.966567*
+    (double) QuantumRange,0.463759*(double) QuantumRange,&h,&s,
+    &i);
+  if ((fabs((double) h-111.244374/360.0) >= ReferenceEpsilon) ||
+      (fabs((double) s-0.295985) >= ReferenceEpsilon) ||
+      (fabs((double) i-0.658734) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -426,9 +428,9 @@ static MagickBooleanType ValidateHSLToRGB()
 
   (void) FormatLocaleFile(stdout,"  HSLToRGB");
   ConvertHSLToRGB(110.200859/360.0,0.882623,0.715163,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -441,8 +443,9 @@ static MagickBooleanType ValidateRGBToHSL()
     s;
 
   (void) FormatLocaleFile(stdout,"  RGBToHSL");
-  ConvertRGBToHSL(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&h,&s,&l);
+  ConvertRGBToHSL(0.545877*(double) QuantumRange,0.966567*
+    (double) QuantumRange,0.463759*(double) QuantumRange,&h,&s,
+    &l);
   if ((fabs(h-110.200859/360.0) >= ReferenceEpsilon) ||
       (fabs(s-0.882623) >= ReferenceEpsilon) ||
       (fabs(l-0.715163) >= ReferenceEpsilon))
@@ -459,9 +462,9 @@ static MagickBooleanType ValidateHSVToRGB()
 
   (void) FormatLocaleFile(stdout,"  HSVToRGB");
   ConvertHSVToRGB(110.200859/360.0,0.520200,0.966567,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -474,8 +477,8 @@ static MagickBooleanType ValidateRGBToHSV()
     v;
 
   (void) FormatLocaleFile(stdout,"  RGBToHSV");
-  ConvertRGBToHSV(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&h,&s,&v);
+  ConvertRGBToHSV(0.545877*(double) QuantumRange,0.966567*(double) QuantumRange,
+    0.463759*(double) QuantumRange,&h,&s,&v);
   if ((fabs(h-110.200859/360.0) >= ReferenceEpsilon) ||
       (fabs(s-0.520200) >= ReferenceEpsilon) ||
       (fabs(v-0.966567) >= ReferenceEpsilon))
@@ -491,8 +494,8 @@ static MagickBooleanType ValidateRGBToJPEGYCbCr()
     Y;
 
   (void) FormatLocaleFile(stdout,"  RGBToJPEGYCbCr");
-  ConvertRGBToYCbCr(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&Y,&Cb,&Cr);
+  ConvertRGBToYCbCr(0.545877*(double) QuantumRange,0.966567*(double)
+    QuantumRange,0.463759*(double) QuantumRange,&Y,&Cb,&Cr);
   if ((fabs(Y-0.783460) >= ReferenceEpsilon) ||
       (fabs(Cb-0.319581) >= ReferenceEpsilon) ||
       (fabs(Cr-0.330539) >= ReferenceEpsilon))
@@ -509,9 +512,9 @@ static MagickBooleanType ValidateJPEGYCbCrToRGB()
 
   (void) FormatLocaleFile(stdout,"  JPEGYCbCrToRGB");
   ConvertYCbCrToRGB(0.783460,0.319581,0.330539,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -526,9 +529,9 @@ static MagickBooleanType ValidateLabToRGB()
   (void) FormatLocaleFile(stdout,"  LabToRGB");
   ConvertLabToRGB(88.456154/100.0,-54.671483/255+0.5,51.662818/255.0+0.5,
     &r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -541,8 +544,9 @@ static MagickBooleanType ValidateRGBToLab()
     L;
 
   (void) FormatLocaleFile(stdout,"  RGBToLab");
-  ConvertRGBToLab(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&L,&a,&b);
+  ConvertRGBToLab(0.545877*(double) QuantumRange,0.966567*
+    (double) QuantumRange,0.463759*(double) QuantumRange,&L,&a,
+    &b);
   if ((fabs(L-(88.456154/100.0)) >= ReferenceEpsilon) ||
       (fabs(a-(-54.671483/255.0+0.5)) >= ReferenceEpsilon) ||
       (fabs(b-(51.662818/255.0+0.5)) >= ReferenceEpsilon))
@@ -560,9 +564,9 @@ static MagickBooleanType ValidateLchToRGB()
   (void) FormatLocaleFile(stdout,"  LchToRGB");
   ConvertLCHabToRGB(88.456154/100.0,75.219797/255.0+0.5,136.620717/360.0,
     &r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -575,8 +579,8 @@ static MagickBooleanType ValidateRGBToLch()
     L;
 
   (void) FormatLocaleFile(stdout,"  RGBToLch");
-  ConvertRGBToLCHab(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&L,&c,&h);
+  ConvertRGBToLCHab(0.545877*(double) QuantumRange,0.966567*(double)
+    QuantumRange,0.463759*(double) QuantumRange,&L,&c,&h);
   if ((fabs(L-88.456154/100.0) >= ReferenceEpsilon) ||
       (fabs(c-(75.219797/255.0+0.5)) >= ReferenceEpsilon) ||
       (fabs(h-(136.620717/255.0+0.5)) >= ReferenceEpsilon))
@@ -592,8 +596,8 @@ static MagickBooleanType ValidateRGBToLMS()
     S;
 
   (void) FormatLocaleFile(stdout,"  RGBToLMS");
-  ConvertRGBToLMS(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&L,&M,&S);
+  ConvertRGBToLMS(0.545877*(double) QuantumRange,0.966567*(double) QuantumRange,
+    0.463759*(double) QuantumRange,&L,&M,&S);
   if ((fabs(L-0.611749) >= ReferenceEpsilon) ||
       (fabs(M-0.910088) >= ReferenceEpsilon) ||
       (fabs(S-0.294880) >= ReferenceEpsilon))
@@ -610,9 +614,9 @@ static MagickBooleanType ValidateLMSToRGB()
 
   (void) FormatLocaleFile(stdout,"  LMSToRGB");
   ConvertLMSToRGB(0.611749,0.910088,0.294880,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -625,8 +629,8 @@ static MagickBooleanType ValidateRGBToLuv()
     v;
 
   (void) FormatLocaleFile(stdout,"  RGBToLuv");
-  ConvertRGBToLuv(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&L,&u,&v);
+  ConvertRGBToLuv(0.545877*(double) QuantumRange,0.966567*(double) QuantumRange,
+    0.463759*(double) QuantumRange,&L,&u,&v);
   if ((fabs(L-88.456154/262.0) >= ReferenceEpsilon) ||
       (fabs(u-(-51.330414+134.0)/354.0) >= ReferenceEpsilon) ||
       (fabs(v-(76.405526+140.0)/262.0) >= ReferenceEpsilon))
@@ -644,9 +648,9 @@ static MagickBooleanType ValidateLuvToRGB()
   (void) FormatLocaleFile(stdout,"  LuvToRGB");
   ConvertLuvToRGB(88.456154/100.0,(-51.330414+134.0)/354.0,
     (76.405526+140.0)/262.0,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -659,8 +663,8 @@ static MagickBooleanType ValidateRGBToXYZ()
     z;
 
   (void) FormatLocaleFile(stdout,"  RGBToXYZ");
-  ConvertRGBToXYZ(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&x,&y,&z);
+  ConvertRGBToXYZ(0.545877*(double) QuantumRange,0.966567*(double) QuantumRange,
+    0.463759*(double) QuantumRange,&x,&y,&z);
   if ((fabs(x-0.470646) >= ReferenceEpsilon) ||
       (fabs(y-0.730178) >= ReferenceEpsilon) ||
       (fabs(z-0.288324) >= ReferenceEpsilon))
@@ -677,9 +681,9 @@ static MagickBooleanType ValidateXYZToRGB()
 
   (void) FormatLocaleFile(stdout,"  XYZToRGB");
   ConvertXYZToRGB(0.470646,0.730178,0.288324,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -693,9 +697,9 @@ static MagickBooleanType ValidateYDbDrToRGB()
 
   (void) FormatLocaleFile(stdout,"  YDbDrToRGB");
   ConvertYDbDrToRGB(0.783460,-0.480932+0.5,0.451670+0.5,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -708,8 +712,8 @@ static MagickBooleanType ValidateRGBToYDbDr()
     Y;
 
   (void) FormatLocaleFile(stdout,"  RGBToYDbDr");
-  ConvertRGBToYDbDr(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&Y,&Db,&Dr);
+  ConvertRGBToYDbDr(0.545877*(double) QuantumRange,0.966567*(double)
+    QuantumRange,0.463759*(double) QuantumRange,&Y,&Db,&Dr);
   if ((fabs(Y-0.783460) >= ReferenceEpsilon) ||
       (fabs(Db-(-0.480932)) >= ReferenceEpsilon) ||
       (fabs(Dr-0.451670) >= ReferenceEpsilon))
@@ -725,8 +729,8 @@ static MagickBooleanType ValidateRGBToYIQ()
     y;
 
   (void) FormatLocaleFile(stdout,"  RGBToYIQ");
-  ConvertRGBToYIQ(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&y,&i,&q);
+  ConvertRGBToYIQ(0.545877*(double) QuantumRange,0.966567*(double) QuantumRange,
+    0.463759*(double) QuantumRange,&y,&i,&q);
   if ((fabs(y-0.783460) >= ReferenceEpsilon) ||
       (fabs(i-(-0.089078)) >= ReferenceEpsilon) ||
       (fabs(q-(-0.245399)) >= ReferenceEpsilon))
@@ -743,9 +747,9 @@ static MagickBooleanType ValidateYIQToRGB()
 
   (void) FormatLocaleFile(stdout,"  YIQToRGB");
   ConvertYIQToRGB(0.783460,-0.089078+0.5,-0.245399+0.5,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -758,8 +762,8 @@ static MagickBooleanType ValidateRGBToYPbPr()
     Y;
 
   (void) FormatLocaleFile(stdout,"  RGBToYPbPr");
-  ConvertRGBToYPbPr(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&Y,&Pb,&Pr);
+  ConvertRGBToYPbPr(0.545877*(double) QuantumRange,0.966567*(double)
+    QuantumRange,0.463759*(double) QuantumRange,&Y,&Pb,&Pr);
   if ((fabs(Y-0.783460) >= ReferenceEpsilon) ||
       (fabs(Pb-(-0.180419)) >= ReferenceEpsilon) ||
       (fabs(Pr-(-0.169461)) >= ReferenceEpsilon))
@@ -776,9 +780,9 @@ static MagickBooleanType ValidateYPbPrToRGB()
 
   (void) FormatLocaleFile(stdout,"  YPbPrToRGB");
   ConvertYPbPrToRGB(0.783460,-0.180419+0.5,-0.169461+0.5,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
@@ -791,8 +795,8 @@ static MagickBooleanType ValidateRGBToYUV()
     Y;
 
   (void) FormatLocaleFile(stdout,"  RGBToYUV");
-  ConvertRGBToYUV(0.545877*QuantumRange,0.966567*QuantumRange,
-    0.463759*QuantumRange,&Y,&U,&V);
+  ConvertRGBToYUV(0.545877*(double) QuantumRange,0.966567*(double)
+    QuantumRange,0.463759*(double) QuantumRange,&Y,&U,&V);
   if ((fabs(Y-0.783460) >= ReferenceEpsilon) ||
       (fabs(U-(-0.157383)) >= ReferenceEpsilon) ||
       (fabs(V-(-0.208443)) >= ReferenceEpsilon))
@@ -809,15 +813,14 @@ static MagickBooleanType ValidateYUVToRGB()
 
   (void) FormatLocaleFile(stdout,"  YUVToRGB");
   ConvertYUVToRGB(0.783460,-0.157383+0.5,-0.208443+0.5,&r,&g,&b);
-  if ((fabs(r-0.545877*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(g-0.966567*QuantumRange) >= ReferenceEpsilon) ||
-      (fabs(b-0.463759*QuantumRange) >= ReferenceEpsilon))
+  if ((fabs((double) r-0.545877*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) g-0.966567*(double) QuantumRange) >= ReferenceEpsilon) ||
+      (fabs((double) b-0.463759*(double) QuantumRange) >= ReferenceEpsilon))
     return(MagickFalse);
   return(MagickTrue);
 }
 
-static size_t ValidateColorspaces(ImageInfo *image_info,size_t *fails,
-  ExceptionInfo *exception)
+static size_t ValidateColorspaces(size_t *fails,ExceptionInfo *exception)
 {
   MagickBooleanType
     status;
@@ -1914,7 +1917,7 @@ static size_t ValidateImportExportPixels(ImageInfo *image_info,
       length=strlen(reference_map[i])*reference_image->columns*
         reference_image->rows*reference_storage[j].quantum;
       pixels=(unsigned char *) AcquireQuantumMemory(length,sizeof(*pixels));
-      if (pixels == (unsigned char *) NULL ||
+      if ((pixels == (unsigned char *) NULL) ||
           (exception->severity >= ErrorException))
         {
           (void) FormatLocaleFile(stdout,"... fail @ %s/%s/%lu.\n",
@@ -2442,7 +2445,7 @@ int main(int argc,char **argv)
             "ImageMagick Validation Suite (%s)\n\n",CommandOptionToMnemonic(
             MagickValidateOptions,(ssize_t) type));
           if ((type & ColorspaceValidate) != 0)
-            tests+=ValidateColorspaces(image_info,&fail,exception);
+            tests+=ValidateColorspaces(&fail,exception);
           if ((type & CompareValidate) != 0)
             tests+=ValidateCompareCommand(image_info,reference_filename,
               output_filename,&fail,exception);
@@ -2502,6 +2505,8 @@ int main(int argc,char **argv)
             (double) tests,(double) (tests-fail),(double) fail);
         }
       (void) RelinquishUniqueFileResource(output_filename);
+      (void) ConcatenateMagickString(output_filename,"-0",MagickPathExtent);
+      (void) RelinquishUniqueFileResource(output_filename);
       (void) RelinquishUniqueFileResource(reference_filename);
     }
   if (exception->severity != UndefinedException)
